cdist-type__keyboard(7)
=======================

NAME
----
cdit-type__keyboard - Set keyboard layout


DESCRIPTION
-----------
This cdist type allows you to modify keyboard layout.


REQUIRED PARAMETERS
-------------------
type
   Any valid type, for example "us"


EXAMPLES
--------

.. code-block:: sh

    # Set keyboard type to "us"
    __keyboard --type "us"


AUTHORS
-------
Carlos Ortigoza <carlos.ortigoza--@--ungleich.ch>


COPYING
-------
Copyright \(C) 2016 Carlos Ortigoza. Free use of this software is
granted under the terms of the GNU General Public License v3 or later (GPLv3+).
